import Vue from 'vue'
import { getCurrentPosition, positionToObject } from './helpers'

export const VueGeolocationApi = Vue.extend({
  data: () => ({
    position: null,
    options: {},
    _interval: null,
    interval: 60,
    loading: false,
  }),
  computed: {
    supported() {
      return 'geolocation' in navigator
    },
    coords() {
      const { position } = this
      return position ? position.coords : null
    },
    timestamp() {
      const { position } = this
      return position ? position.coords : null
    },
    geoJSON() {
      const { coords } = this
      if (!coords) return null
      const { latitude, longitude, altitude } = coords
      const coordinates = [latitude, longitude]
      return altitude === null ? coordinates : [...coordinates, altitude]
    },
  },
  watch: {
    interval: 'watch',
  },
  beforeDestroy() {
    this.clearTimer()
  },
  created() {
    console.log('geo')
    if (!process.client) return
    console.log('geo2')
    this.watch(true)
  },
  methods: {
    watch(mandatory) {
      const { interval } = this
      this.clearTimer()
      if (!interval) return
      this.$nextTick(() => {
        this._interval = setInterval(
          () => this.getCurrentPosition(),
          interval * 1000
        )
        if (mandatory) this.getCurrentPosition()
      })
    },
    clearTimer() {
      const { _interval } = this
      if (!_interval) return
      clearInterval(_interval)
    },
    async getCurrentPosition(options) {
      if (!this.suported) return
      const params = Object.assign({}, this.options, options || {})
      this.loading = true
      const response = await getCurrentPosition(params)
      const position = positionToObject(response)
      this.position = position
      this.loading = false
      return position
    },
  },
})

export default VueGeolocationApi
